part of 'customer_support_cubit.dart';

abstract class CustomerSupportState extends Equatable{
  const CustomerSupportState();
  @override
  List<Object> get props => [];
}

class CustomerSupportInitial extends CustomerSupportState {}
class SupportLoading extends CustomerSupportState {
  SupportLoading();
  @override
  String toString() => 'ChangePassLoading';
}
class SupportFailure extends CustomerSupportState {
  final String error;

  SupportFailure(this.error);

  @override
  String toString() => 'ChangePassFailure { error: $error }';
}
class SupportSuccess extends CustomerSupportState {
  @override
  String toString() => 'SupportSuccess';
}